####### Function agbarplot Barplot with all cool things ########################
### Created: 180425 Author: Alfonso Garmendia  algarsal at upvnet dot upv dot es

### v0.0.4 180512: Add roxygen2 documentation.
### V0.0.3 180510: xangle and horizontal justification.
### V0.0.2 180426: Working version.
### V0.0.1: Still not Working version.
#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

#### Roxigen ####
#' Barplot figure with means, standard errors and posthoc letters.
#'
#' Barplot figure with means, standard errors and posthoc letters.
#' The letters must be provided from previous analyses, so it can be used for
#' anova, kruskal or other analyses.
#'
#' @param df0 Data frame
#' @param x String or number pointing to the x variable inside "Data"
#'  dataframe. Should be a factor.
#' @param y String or number pointing to the y variable inside "Data"
#'  dataframe. Should be numeric.
#' @param ... Names needed for next parameters.
#' @param xlab0 Changes the x axis label in barplot.
#' @param ylab0 Changes the y axis label in barplot.
#' @param letters0 Post Hoc letters to include into the barplot.
#' @param lettersheight Changes the letters height in the barplot.
#' Default = mean(Data[[y]]) / 4
#' @param ggtheme Changes theme for barplot. Default = ggplot2::theme_bw().
#' @param xangle Changes the angle of text for x axis label in barplot.
#' @param hjust Changes the horizontal justification of text for x axis label
#' in barplot.
#' @import ggplot2
#' @return
#' A list with the barplot and the caption of the barplot:
#'
#' - $barplot
#'
#' - $caption
#'
#' @export
#'
#' @examples
#'
#' agbarplot(iris, 5, 1, letters0 = c("a", "b", "c"))
#' agbarplot(iris, 5, 1, letters0 = c("a", "b")) # error
#' agbarplot(iris, 5, 1, letters0 = c("a", "b", "c"), ylab0 = "Sepal length (cm)")
#'
#' @details
#' Require ggplot2 active.
#'
#' @author Alfonso Garmendia (Universitat Politècnica de València)
#'
#### Init ####
# df0 <- iris
# x <- 5
# # x <- "Species"
# y <- 1
# letters0 = c("a", "b", "c")
# letters0 = c("a", "b")

# df0 <- Data
# df0 = Data, x = x, y = y, xlab0 = xlab0, ylab0 = ylab0,
# letters0 = TabA$HSD, lettersheight = lettersheight,
# ggtheme = ggtheme

#### Function ####
agbarplot <- function(df0, x, y, ..., xlab0 = NULL, ylab0 = NULL,
                      letters0 = NULL, lettersheight = mean(df0[[y]]) / 4,
                      ggtheme = ggplot2::theme_bw(),
                      xangle = NULL, hjust = NULL){
  #### Description ####
  ### INPUT
  ### df0, data frame
  ### x, a number for factor variable
  ### y, a number for numeric variable
  ### letters0, letters from anova or Kruskal-Wallis post hoc. If null not added
  ### lettersheight, vertical position for letters
  ### ggtheme, theme for ggplot
  #### OUTPUT
  ### A ggplot object with a barplot.

  #### Require ####
  # agrequire("ggplot2")

  #### Check variables ####
  if (1 == 1) {
    ### df0 ####
    if (!is.data.frame(df0)) as.data.frame(df0)
    if (!is.data.frame(df0)) stop("df0 needs to be a data frame in agbarplot()")

    ### x numeric or character ####
    if (is.character(x)) {
      # nx <- x
      if (!any(names(df0) %in% x)) {
        stop(paste("x is not a variable name of df0 in agbarplot().",
                   "It can be a variable name or number."))
      }
      if (any(names(df0) %in% x)) x <- which(names(df0) %in% x)

    }
    if (!is.integer(x)) x <- as.integer(x)
    if (!is.integer(x)) stop(paste("x is not a variable number of df0 in",
                                   "agbarplot(). It can be a variable name or",
                                   " number."))
    ### x as factor ####
    if (!is.factor(df0[[x]])) df0[[x]] <- as.factor(df0[[x]])
    if (!is.factor(df0[[x]])) {
      stop("In agbarplot(), x needs to point to a factor variable.")
    }

    ### y numeric or character ####
    if (is.character(y)) {
      # ny <- y
      if (!any(names(df0) %in% y)) {
        stop(paste("y is not a variable name of df0 in agbarplot().",
                   "It can be a variable name or number."))
      }
      if (any(names(df0) %in% y)) y <- which(names(df0) %in% y)

    }
    if (!is.integer(y)) y <- as.integer(y)
    if (!is.integer(y)) stop(paste("y is not a variable number of df0 in",
                                   "agbarplot(). It can be a variable name or",
                                   " number."))

    ### y as numeric ####
    if (!is.numeric(df0[[y]])) df0[[y]] <- as.numeric(df0[[y]])
    if (!is.numeric(df0[[y]])) {
      stop("In agbarplot(), y needs to point to a numeric variable.")
    }

    ### letters0 ####
    if (!is.null(letters0)) {
      if (!length(levels(df0[[x]])) == length(letters0)) {
        stop("In agbarplot(), letters0 must be same length than levels of x.")
      }
    }
  }

  #### Variables names for labels ####
  if (is.null(xlab0)) xlab0 <- names(df0)[x]
  if (is.null(ylab0)) ylab0 <- names(df0)[y]

  #### Means and standard errors ####
  # df0[y] %>%
  #   group_by(df0[,x]) %>%
  #   summarise_each(funs(mean, sd))
  df0 <- as.data.frame(df0)
  D <- aggregate(df0[,y] ~ df0[,x], df0,
                 function(x) c(mean = mean(x),
                               sd = sd(x),
                               #computation of the standard error of the mean
                               se = sd(x)/sqrt(length(x))
                 ))
  D <- cbind(D[1], D[[2]])
  # str(D)
  names(D) <- c("variable", "Mean", "sd0", "se0")

  #### Plot ####
  BP <- ggplot(D, aes(x = D[, 1]
                      , y = D[, 2]
  )) +
    geom_bar(stat = "identity", aes(color = D[, 1]
                                    , fill = D[, 1]
                                    # , alpha = 0.5
    )) +
    geom_errorbar(aes(ymin = Mean - se0, ymax = Mean + se0, width = .1)) +

    ### Axis labels
    labs(x = xlab0, y = ylab0) +

    ### Legend remove
    guides(fill = FALSE, color = FALSE)

  #### Add Theme ####
  BP <- BP + ggtheme

  #### Add letters to plot ####
  capletters <- ""
  if (!is.null(letters0)) {
    BP <- BP + geom_text(aes(y = lettersheight, label = letters0),
                         colour = "black",
                         size = 6)
  }

  #### rotate xlab if necessary ####
  BP <- BP + theme(axis.text.x = element_text(angle = xangle, hjust = hjust))

  #### Caption ####
  caption <- paste0("Barplot for differences of ", ylab0, " on ", xlab0,
                    ".")
  #### Return ####
  out <- list()
  out$barplot <- BP
  out$caption <- caption

  return(out)
}
