####### Function agchisquare Chi square analysis and plot ######################
### Created: 180430 Author: Alfonso Garmendia  algarsal at upvnet dot upv dot es

### v0.0.3 180512: Add roxygen2 documentation.
### V0.0.2: Working version
### V0.0.1: Still not Working version
#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
#### Roxigen ####
#' Chi-square analysis and plot
#'
#' Performs a chi-square analyses with the frequencies of two factors in
#' a data frame. Letters from posthoc analyses can be provided. They can be
#' calculated using fifer::chisq.post.hoc(), but it only gives the p.
#' The function agautoanalyses::agchisqposthoc() is an attempt to extract this
#' letters automatically.
#'
#' @param df0 A data frame.
#' @param x String or number pointing to the x variable inside "Data"
#'  dataframe. Should be a factor.
#' @param y String or number pointing to the y variable inside "Data"
#'  dataframe. Should be logic (TRUE/FALSE) variable.
#' @param ... Names needed for next parameters.
#' @param xlab0 Changes the x axis label in plots.
#' @param ylab0 Changes the y axis label in plots.
#' @param StackBarPlot If plot in output (TRUE/FALSE).
#' @param PercentBarPlot If plot in output (TRUE/FALSE).
#' @param alpha0 Significance level for groups separation. And for captions.
#' @param digits Digits for numbers in plots.
#' @param ggtheme Theme for ggplot.
#' @param lettersheightstack Letters height  in the stack bars plot.
#' @param lettersheightpercent Letters height in the percent bars plot.
#' @param letters0 Letters from Post Hoc analyses. In the future they should be
#' automatically calculated with agchisqposthoc(), but still not working.
#' @param letters0col Colour for letters.
#' @param letters0size Size for letters.
#' @param percsize Size for percentages numbers in plots.
#' @param perccolor Colour for percentages numbers in plots.
#'
#' @return
#' A list with plots, tables, captions and texts:
#'
#' - $plots$stack, Stacked bars plot.
#'
#' - $plots$percent, Percentage bars plot.
#'
#' - $capplots$stack, Caption for plot.
#'
#' - $capplots$percent, Caption for plot.
#'
#' - $tables$expected, Table of expected values.
#'
#' - $tables$pval, Table of p values.
#'
#' - $captables$expected, Caption for the table of expected values.
#'
#' - $captables$pval, Caption for the table of p values.
#'
#' - $texts$bibliography, Text with relevant bibliography for citation.
#'
#' @import ggplot2
#'
#' @export
#'
#' @examples
#' df0 <- iris
#' df0$tf <- rep(c(TRUE, TRUE, FALSE))
#' agchisquare(df0, 5, 6)
#'
#' @details
#' Require ggplot2.
#'
#' @seealso
#' ggplot, agrequire
#'
#' @author Alfonso Garmendia (Universitat Politècnica de València)
#'
#### Init ####
# df0 <- iris
# df0$sepallengthtf <- df0$Sepal.Length < 5
# x <- 5
# y <- 6
# xlab0 = NULL
# ylab0 <- "Small sepal length (< 5)"
# ggtheme = ggplot2::theme_bw()
# alpha0 = 0.05
# letters0 <- c("a", "b", "c")
# StackBarPlot = TRUE
# PercentBarPlot = TRUE
# alpha0 = 0.05
# digits = 2
# ggtheme = ggplot2::theme_bw()
# lettersheightstack = NULL
# lettersheightpercent = NULL
# letters0col = "black"
# letters0size = 3

#### FUNCTION ####
#### Figure barplot with means, standard error and letters ###
agchisquare <-
  function(df0, x, y, ... , xlab0 = NULL, ylab0 = NULL,
           StackBarPlot = TRUE, PercentBarPlot = TRUE,
           alpha0 = 0.05, digits = 2, ggtheme = ggplot2::theme_bw(),
           lettersheightstack = NULL, lettersheightpercent = NULL,
           letters0 = NULL,  letters0col = "black", letters0size = 6,
           percsize = 4, perccolor = "black"){
    #### Require ####
    # agrequire("ggplot2")

    #### Check variables ####
    if (1 == 1) {
      ### df0 ####
      df0 <- as.data.frame(df0)
      if (!is.data.frame(df0)) stop(paste("df0 needs to be a data frame",
                                          "in agchisquare()"))

      ### x numeric or character ####
      if (is.character(x)) { # if character converts to numeric (which variable)
        # nx <- x
        if (!any(names(df0) %in% x)) {
          stop(paste("x is not a variable name of df0 in agchisquare().",
                     "It can be a variable name or number."))
        }
        if (any(names(df0) %in% x)) x <- which(names(df0) %in% x)
      }

      if (!is.integer(x)) x <- as.integer(x)

      if (!is.integer(x)) stop(paste("x is not a variable number of df0 in",
                                     "agchisquare(). It can be a variable",
                                     "name or number."))
      ### x as factor ####
      df0[[x]] <- as.factor(df0[[x]])
      if (!is.factor(df0[[x]])) {
        stop("In agchisquare(), x needs to point to a factor variable.")
      }

      ### y numeric or character ####
      if (is.character(y)) { # if character converts to numeric (which variable)
        # ny <- y
        if (!any(names(df0) %in% y)) {
          stop(paste("y is not a variable name of df0 in agchisquare().",
                     "It can be a variable name or number."))
        }
        y <- which(names(df0) %in% y)
      }

      y <- as.integer(y)

      if (!is.integer(y)) stop(paste("y is not a variable number of df0 in",
                                     "agchisquare(). It can be a variable",
                                     "name or number."))

      # ### y as numeric ####
      # if (!is.numeric(df0[[y]])) df0[[y]] <- as.numeric(df0[[y]])
      # if (!is.numeric(df0[[y]])) {
      #   stop("In agchisquare(), y needs to point to a numeric variable.")
      # }
      #
      ###  Variables names for labels ####
      if (is.null(xlab0)) xlab0 <- names(df0)[x]
      if (is.null(ylab0)) ylab0 <- names(df0)[y]
      }

    #### ANALYSIS ####
    t1 <- table(df0[ , x], df0[ , y])
    # str(t1)
    (ch <- chisq.test(t1))
    txt1 <- ""
    if (any(ch$expected < 5)) txt1 <-
      paste("Expected values < 5 , Chi-squared approximation may be incorrect",
            "for", xlab0, "and", ylab0, "in agchisquare()")

    #### Table expected ####
    t1df <- as.data.frame.matrix(t1)

    expected <- as.data.frame.matrix(ch$expected)
    names(expected) <- paste0("expected-", names(t1df))

    expect <- cbind(t1df, expected)

    capexpect <- paste0("Observed and expected values for ", ylab0,
                       " in the different ", xlab0, ".")

    #### Post Hoc ####
    (ph <- agchisqposthoc(t1, control = "holm", digits = digits))
    # (ph <- fifer::chisq.post.hoc(t1, control = "holm", popsInRows = FALSE))

    capph <- paste0("Raw p value and adjusted p value for each pair of ", xlab0,
                    ". For chi-square post-hoc analyses was used a ",
                   "Fisher test with Holm's correction method (Holm 1979). ",
                   "Total chisq p = ", format(ch$p.value, digits = digits),
                   ". Chisq = ", round(ch$statistic, digits = digits),
                   ". ", txt1)

    bibl <- paste("Holm, S. (1979). A simple sequentially rejective multiple",
                   "test procedure.",
                   "Scandinavian Journal of Statistics 6, 65–70.")

    #### Plots data ####
      D <- as.data.frame(t1)
      D$total <-                                # sums all same names in Var1
        sapply(D$Var1,
               function(caseID) sum(subset(D,
                                           Var1 == caseID)$Freq))

      D$percent <- round((D$Freq/D$total)*100,2)

      #### Stacks bars plot ####
      if (StackBarPlot) {
        ### First plot ####
        bps <- ggplot(D, aes(x = Var1, y = Freq, fill = Var2)) +
          geom_bar(stat = "identity", position = "stack") +
          labs(x = xlab0, y = "Frequency")

        ### Frequencies ####
        freq = ggplot_build(bps)$data[[1]]
        freq$y_pos = (freq$ymin + freq$ymax) / 2
        Dord <- D[order(D$Var2, decreasing = TRUE), ]
        Dord <- Dord[order(Dord$Var1), ]

        bps <- bps +
          annotate(x = freq$x,
                   y = freq$y_pos,
                   label = Dord$Freq,
                   geom = "text", size = percsize, color = perccolor)

        #### Legend and theme ####
        bps <- bps +
          guides(fill = guide_legend(title = ylab0), color = FALSE) +
          ggtheme

        #### Add letters0 to plot ####
        if (!is.null(letters0)) {                         # If there are letters
          #### If number of letters is not right ####
          if (!length(levels(D$Var1)) == length(letters0)) {
            stop(paste("In agchisquare(),",
                       "letters0 must be same length than levels of x variable."))
          }

          #### If number of letters is right ####
          if (length(levels(D$Var1)) == length(letters0)) {
            #### Calculate letters height if necessary ####
            if (!is.numeric(lettersheightstack)) lettersheightstack <-
                mean(na.exclude(D$Freq)) / 3

            #### Data frame for letters ####
            Dletters <-
              data.frame(varx = levels(D$Var1), yy = letters0, Var2 = NA)

            #### Add letters to plot ####
            bps <- bps +
              geom_text(data = Dletters,
                        aes(y = lettersheightstack, x = varx, label = yy),
                        colour = letters0col, size = letters0size)
          }
        }

        ### Capplots ####
        capplotstack <- paste("Frequencies of ", ylab0, " on ", xlab0, ".")
        }

      #### Percent (filled) bar plot ####
      if (PercentBarPlot) {
        ### First plot ####
        bpp <- ggplot(D, aes(x = Var1, y = percent, fill = Var2)) +
          geom_bar(stat = "identity", position = "stack") +
          labs(x = xlab0, y = "Percent")

          ### Percents ####
          freq = ggplot_build(bpp)$data[[1]]
          freq$y_pos = (freq$ymin + freq$ymax) / 2
          Dord <- D[order(D$Var2, decreasing = TRUE), ]
          Dord <- Dord[order(Dord$Var1), ]

          bpp <- bpp +
          annotate(x = freq$x,
                   y = freq$y_pos,
                   label = paste(Dord$percent, "%"),
                   geom = "text", size = percsize, color = perccolor)
      #### Legend and theme ####
      bpp <- bpp +
        guides(fill = guide_legend(title = ylab0), color = FALSE) +
        ggtheme

      #### Add letters0 to plot ####
      if (!is.null(letters0)) {                         # If there are letters
        #### If number of letters is not right ####
        if (!length(levels(D$Var1)) == length(letters0)) {
          stop(paste("In agchisquare(),",
                     "letters0 must be same length than levels of x variable."))
        }

        #### If number of letters is right ####
        if (length(levels(D$Var1)) == length(letters0)) {
          #### Calculate letters height if necessary ####
          if (!is.numeric(lettersheightpercent)) lettersheightpercent <-
              mean(na.exclude(D$Freq)) / 3

          #### Data frame for letters ####
          Dletters <-
            data.frame(varx = levels(D$Var1), yy = letters0, Var2 = NA)

          #### Add letters to plot ####
          bpp <- bpp + geom_text(data = Dletters,
                               aes(y = lettersheightpercent, x = varx, label = yy),
                               colour = letters0col, size = letters0size)
        }
      }

        ### Capplots ####
        capplotpercent <- paste("Percents of ", ylab0, " on ", xlab0, ".")
      }

    #### Return ####
    out <- list()
    if (StackBarPlot) {
      out$plots$stack <- bps
      out$capplots$stack <- capplotstack
    }
    if (PercentBarPlot) {
      out$plots$percent <- bpp
      out$capplots$percent <- capplotpercent
    }
    out$tables$expected <- expect
    out$captables$expected <- capexpect
    out$tables$pval <- ph
    out$captables$pval <- capph
    out$texts$bibliography <- bibl

    return(out)
  }
