####### Function aginteractionaov Analysis of interaction and barplot ##########
### Created: 180429 Author: Alfonso Garmendia  algarsal at upvnet dot upv dot es

### v0.0.3 180512: Add roxygen2 documentation.
### V0.0.2 180429: Working version with plot, caption, anova, hsd,
###                hsd letters between groups and within groups.
### V0.0.1: Still not Working version
#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

#### Roxigen ####
#' Anova for interaction.
#'
#' Analisis of variance and barplot for the interaction of two factors in a
#' numerical variable.
#'
#' @param df0 Data frame
#' @param x String or number pointing to the x variable inside "Data"
#'     dataframe. Should be a factor.
#' @param y String or number pointing to the y variable inside "Data"
#'     dataframe. Should be numeric.
#' @param cov String or number pointing to the covariate inside "Data"
#'     dataframe. Should be a factor.
#' @param ... Names needed for next parameters.
#' @param xlab0 Changes the x axis label in barplot.
#' @param ylab0 Changes the y axis label in barplot.
#' @param covlab Changes the covariate label in barplot.
#' @param lettersheight0 Changes the letters0 height in the barplot.
#'     Default = max(df2$Mean) + max(df2$Mean) / 5
#' @param lettersheightcov Changes the letterscov height in the barplot.
#'     Default = mean(na.exclude(df0[[y]])) / 4
#' @param letters0size Changes the size of the letters0. Default = 6.
#' @param letterscovsize Changes the size of the letterscov. Default = 5.
#' @param letters0col Changes the colour of the letters0. Default = "darkgrey".
#' @param letterscovcol Changes the colour of the letterscov. Default = "black".
#' @param ggtheme Changes theme for barplot. Default = ggplot2::theme_bw().
#' @param alpha0 Significance level for groups in post hoc analyses.
#'     Default = 0.05.
#'
#' @return
#' A list with:
#'
#' - $plot <- A ggplot object with a barplot with covariate bars for each.
#'       x variable.
#'
#' - $capplot <- Caption for the plot.
#'
#' - $anova <- Table for ANOVA analysis.
#'
#' - $hsd0 <- hsd distance.
#'
#' - $letters0 <- letters for hsd between groups.
#'
#' - $letters1 <- letters for hsd in each group.
#'
#' @export
#'
#' @examples
#' df0 <- iris
#' df0$cov <- rep(c("A", "B", "C"), 50)
#' aginteractionaov(df0, x = 5, y = 1, cov = 6, covlab = "FakeGroup",
#'                      letters0col = "red")
#'
#' @details
#' Require ggplot2.
#' Uses agbarplotinteraction and agaovhsd.
#'
#' @seealso
#' agbarplotinteraction, agaovhsd
#'
#' @author Alfonso Garmendia (Universitat Politècnica de València)
#'
#'
#### Init ####
# df0 <- iris
# df0$cov <- rep(c("a", "b", "c"), 50)
# x <- 5
# y <- 1
# cov <- 6
# xlab0 = NULL
# ylab0 <- "Sepal width (cm)"
# covlab <- "Covariate ordered"
# lettersheight0 = NULL
# letters0size = 6
# lettersheightcov = NULL
# letterscovsize = 5
# letters0col = "darkgrey"
# letterscovcol = "black"
# ggtheme = ggplot2::theme_bw()
# alpha0 = 0.05

# df0 <- Fruit
# x <- 2
# y <- 6
# cov <- 8
# xlab0 = NULL
# ylab0 <- "Number of seeds"
# covlab <- "Sample blocks"
# lettersheight0 = NULL
# letters0size = 6
# lettersheightcov = NULL
# letterscovsize = 5
# letters0col = "darkgrey"
# letterscovcol = "black"
# ggtheme = ggplot2::theme_bw()
# alpha0 = 0.05

#### FUNCTION ####
#### Figure barplot with means, standard error and letters ###
aginteractionaov <-
  function(df0, x, y, cov, ... , xlab0 = NULL, ylab0 = NULL, covlab = NULL,
           lettersheight0 = NULL, lettersheightcov = NULL,
           letters0size = 6, letterscovsize = 5,
           letters0col = "darkgrey", letterscovcol = "black",
           ggtheme = ggplot2::theme_bw(), alpha0 = 0.05){
    #### Description ####
    ### INPUT
    ### df0, data frame
    ### x, a number for factor variable
    ### y, a number for numeric variable
    ### cov, a number for factor covariate variable
    ### xlab0, label for x variable
    ### ylab0, label for y variable
    ### covlab, label for covariate variable
    ### lettersheight0, vertical position for letters0
    ### lettersheightcov, vertical position for letterscov
    ### letters0size, size of letters for x levels
    ### letterscovsize, size of letters for covariate into x levels
    ### letters0col, colour of letters for x levels
    ### letterscovcol, colour of letters for covariate into x levels,
    ### ggtheme, theme for ggplot
    #### OUTPUT
    ### A ggplot object with a barplot with covariate bars for each x variable.
    ### Caption for the plot
    ### Table for ANOVA analysis
    ### hsd distance
    ### letters for hsd between groups
    ### letters for hsd in each group.

    #### Require ####
    # Requires agbarplotinteraction for barplot
    if (!exists("agbarplotinteraction")) {
      warning("agbarplotinteraction() needed for aginteractionaov()")
    }
    if (!exists("agaovhsd")) warning("agaovhsd() needed for aginteractionaov()")

    #### Check variables ####
    if (1 == 1) {
      ### df0 ####
      df0 <- as.data.frame(df0)
      if (!is.data.frame(df0)) stop("df0 needs to be a data frame in aginteractionaov()")

      ### x numeric or character ####
      if (is.character(x)) {
        # nx <- x
        if (!any(names(df0) %in% x)) {
          stop(paste("x is not a variable name of df0 in aginteractionaov().",
                     "It can be a variable name or number."))
        }
        if (any(names(df0) %in% x)) x <- which(names(df0) %in% x)

      }
      if (!is.integer(x)) x <- as.integer(x)
      if (!is.integer(x)) stop(paste("x is not a variable number of df0 in",
                                     "aginteractionaov(). It can be a variable name or",
                                     " number."))
      ### x as factor ####
      df0[[x]] <- as.factor(df0[[x]])
      if (!is.factor(df0[[x]])) {
        stop("In aginteractionaov(), x needs to point to a factor variable.")
      }

      ### y numeric or character ####
      if (is.character(y)) {
        # ny <- y
        if (!any(names(df0) %in% y)) {
          stop(paste("y is not a variable name of df0 in aginteractionaov().",
                     "It can be a variable name or number."))
        }
        if (any(names(df0) %in% y)) y <- which(names(df0) %in% y)

      }
      if (!is.integer(y)) y <- as.integer(y)
      if (!is.integer(y)) stop(paste("y is not a variable number of df0 in",
                                     "aginteractionaov(). It can be a variable name or",
                                     " number."))

      ### y as numeric ####
      if (!is.numeric(df0[[y]])) df0[[y]] <- as.numeric(df0[[y]])
      if (!is.numeric(df0[[y]])) {
        stop("In aginteractionaov(), y needs to point to a numeric variable.")
      }

      ### cov numeric or character ####
      if (is.character(cov)) {
        # ny <- cov
        if (!any(names(df0) %in% cov)) {
          stop(paste("cov is not a variable name of df0 in aginteractionaov().",
                     "It can be a variable name or number."))
        }
        if (any(names(df0) %in% cov)) cov <- which(names(df0) %in% cov)

      }
      if (!is.integer(cov)) cov <- as.integer(cov)
      if (!is.integer(cov)) stop(paste("cov is not a variable number of df0 in",
                                       "aginteractionaov(). It can be a variable name or",
                                       " number."))

      ### cov as factor ####
      df0[[cov]] <- as.factor(df0[[cov]])
      if (!is.factor(df0[[cov]])) {
        stop("In aginteractionaov(), cov needs to point to a factor variable.")
      }
      ###  Variables names for labels
      if (is.null(xlab0)) xlab0 <- names(df0)[x]
      if (is.null(ylab0)) ylab0 <- names(df0)[y]
      if (is.null(covlab)) covlab <- names(df0)[cov]
    }

    #### Labels HSD Tuckey #####
    xn <- names(df0)[x]
    yn <- names(df0)[y]
    covn <- names(df0)[cov]
    MT <- agaovhsd(df0, xn, yn, barplot = FALSE, alpha0 = alpha0)
    lab1 <- data.frame(MT$TA[c(1, 4)])

    ### Labels for each column
    LMT <- hsd <- list()
    lev = levels(as.factor(df0[[x]]))
    # i = lev[1]
    # i = lev[5]
    for (i in lev) {
      dfsub <- df0[as.character(df0[ ,x]) == i, ]
      a <- agaovhsd(Data = dfsub, alpha0 = alpha0,
                    barplot = FALSE, x = covn, y = yn)
      hsd[[i]] <- a$TB$HSD
      a <- a$TA[c(1, 4)]
      a$HSD <- as.character(a$HSD)
      LMT[[i]] <- a
    }

    xx <- HSD <- covar <- character()
    for (i in names(LMT)) {
      xx <- c(xx, rep(i, length(levels(as.factor(df0[[cov]])))))
      HSD <- c(HSD, LMT[[i]]$HSD)
      covar <- c(covar, as.character(LMT[[i]][[1]]))
    }

    lab2 <- data.frame(x = xx, cov = covar, HSD = HSD)

    #### PLOT ####
    P <- agbarplotinteraction(df0 = df0, x = x, y = y, cov = cov,
                              xlab0 = xlab0, ylab0 = ylab0, covlab = covlab,
                              letters0 =  lab1$HSD, letterscov = lab2$HSD,
                              lettersheight0 = lettersheight0,
                              lettersheightcov = lettersheightcov,
                              letters0size = letters0size,
                              letterscovsize = letterscovsize,
                              letters0col = letters0col,
                              letterscovcol = letterscovcol,
                              ggtheme = ggtheme)

    P <- P + scale_fill_discrete(breaks = levels(df0[[cov]]))

    #### Anova of the interaction ####
    A <- aov(df0[ , y] ~ df0[ , cov] * df0[ , x])
    An <- anova(A)
    rownames(An)[1:3] <- c(covlab, xlab0,
                           paste("Interaction of", covlab, "and", xlab0))
    attr(An, "heading")[2] <- paste("Response:", ylab0)

    #### Caption ####

    ### Significances
    xeffect <- coveffect <- inteffect <- "non-significant"
    if (An$`Pr(>F)`[2] < alpha0) xeffect <- "significant"
    if (An$`Pr(>F)`[1] < alpha0) coveffect <- "significant"
    if (An$`Pr(>F)`[3] < alpha0) inteffect <- "significant"
    p1 <- format(An$`Pr(>F)`[1], digits = 2)
    p2 <- format(An$`Pr(>F)`[2], digits = 2)
    p3 <- format(An$`Pr(>F)`[3], digits = 2)

    ### CAPTION
    cap <- paste0("Interaction plot for the effect of ", xlab0, " and ", covlab,
                 " on ", ylab0, ". Upper letters (", letters0col,
                 ") denote significance between ", xlab0,
                 " while lower letters (", letterscovcol,
                 ") denote significance between ", covlab, " inside each ",
                 xlab0, ". Same letters implies non-significant differences ",
                 "for alpha = ", alpha0, ". The global effect over ", ylab0,
                 " is ", xeffect, " from ", xlab0,
                 " (p = " , p2, ") , ", coveffect,
                 " from ", covlab, " (p = " , p1,
                 ") and ", inteffect,
                 " from the interaction of both (p = " ,
                 p3, ").")

    #### Return ####
    out <- list()
    out$plot <- P
    out$capplot <- cap
    out$anova <- An
    out$hsd0 <- MT$hsd
    out$letters0 <- lab1
    out$letters1 <- lab2

    return(out)
  }
