% Generated by roxygen2: do not edit by hand
% Please edit documentation in
%   R/Function_aganovas_anova-kruskal-several-variables.R
\name{aganovas}
\alias{aganovas}
\title{Anovas and Kruskal Wallis}
\usage{
aganovas(df0, x, y, ..., res = NULL, lettersheightbarplot = NULL,
  lettersheightviolin = NULL, alpha0 = 0.05,
  ggtheme = ggplot2::theme_bw(), aov = TRUE, kw = TRUE,
  maxlevels = 9, barplot = TRUE, violin = TRUE, histog = TRUE,
  xlabs = NULL, ylabs = NULL, xangle = NULL, xhjust = NULL)
}
\arguments{
\item{df0}{A data frame}

\item{x}{Numbers or character vector pointing to the x variable inside "df0"
dataframe. Should be a factor variable.}

\item{y}{Numbers or character vector pointing to the y variable inside "df0"
dataframe. Should be a numeric variable.}

\item{...}{Names needed for next parameters.}

\item{res}{List of results to add the results to. Default to NULL (new list).}

\item{lettersheightbarplot}{Changes the letters height in the barplots.
Default NULL, lettersheightbarplot = mean(df0[[y]]) / 4}

\item{lettersheightviolin}{Changes the letters height in the violin plots.
Default NULL,
lettersheightviolin = max(df0[[y]]) + ((max(df0[[y]]) - min(df0[[y]])) / 4)}

\item{alpha0}{Significance level for post hoc letters.}

\item{ggtheme}{Theme for ggplot barplot. Default = ggplot2::theme_bw().}

\item{aov}{If ANOVA analyses are wanted. Default TRUE.}

\item{kw}{If Kruskal Wallis analyses are wanted. Default TRUE.}

\item{maxlevels}{Maximum number of levels for categorical vars to be
considered. It should be 9 or less. If more, the densities
plots will not have enough colors.}

\item{barplot}{If barplot is wanted in the output. Default TRUE.}

\item{violin}{If violin plot is wanted in the output. Default TRUE.}

\item{histog}{If histograms plot is wanted in the output. Default TRUE.}

\item{xlabs}{Changes the x axis labels in plots.}

\item{ylabs}{Changes the y axis labels in plots.}

\item{xangle}{Changes the angle of text for x axis label in plots.}

\item{xhjust}{Changes the horizontal justification of text for x axis label
in plots.}
}
\value{
A list with sublists for each dependent variable and sublists for  plots,
plot captions (capplots), tables and tables captions (captables).

For each independent and dependent variable, the format will be:

- $Aov_dependent$independent$plots$plotname
- $Aov_dependent$independent$capplots$plotname
- $Aov_dependent$independent$tables$tablename
- $Aov_dependent$independent$captables$tablename

If a results list is pointed in parameters,
it will add the results to this list.
}
\description{
Aggregates into the same list the results of several parametric (anovas)
and non-parametric (Kruskal-Wallis) analyses for several independent factors
and dependent numeric variables.
}
\details{
Each analysis uses \code{\link{agaovhsd}} for anovas and
\code{\link{agkruskalfigs}} for kruskal wallis analyses.
}
\examples{
A <- aganovas(df0 = iris, x = 5, y = 3:4)
A

df0 <- iris
df0$fakevar <- rep(c(TRUE, TRUE, FALSE))
A <- aganovas(df0 = iris, x = 5:6, y = 3:4)
A


}
\seealso{
\code{\link{agaovhsd}} for details on the analyses of variance (anova) and
\code{\link{agkruskalfigs}} for details on the non-parametric Kruskal-Wallis
analyses. Also \code{\link{agTanovas}} and \code{\link{agTkruskal}} are used
for the summary tables.
}
\author{
Alfonso Garmendia (Universitat Politècnica de València)
}
