% Generated by roxygen2: do not edit by hand
% Please edit documentation in
%   R/Function_agkruskalfigs_KruskalWallis_conFiguras.R
\name{agkruskalfigs}
\alias{agkruskalfigs}
\title{Kruskal Wallis test, post hoc and figures.}
\usage{
agkruskalfigs(df0, x, y, xlab0 = NULL, ylab0 = c("mean", "density"),
  lettersheight = mean(df0[[y]])/4, maxlevels = 9)
}
\arguments{
\item{df0}{A data frame.}

\item{x}{String pointing to the x variable inside "df0"
dataframe. Should be a factor variable.}

\item{y}{String pointing to the y variable inside "df0"
dataframe. Should be a numeric variable.}

\item{lettersheight}{Changes the letters0 height in the barplot.
Default = mean(df0[[y]]) / 4}

\item{xlab}{Changes the x axis label in barplot.}

\item{ylab}{Changes the y axis label in barplot.}
}
\value{
A list with:

- $tables$kw <-  Table with Principal statistics: mean, standard deviation,
      standard error, skewness, kurtosis, shapiro.test for normality,
      Kruskal Wallis.

- $captables$kw <- Caption.

- $plots$BarPlot <- Barplot.

- $plots$Histogram <- Histogram.

- $capplots$BarPlot <- Caption for barplot.

- $capplots$Histogram <- Caption for histogram.

- $plots$Densities <- Densities plot.

- $capplots$Densities <- Caption for densities plot.

- $statistics <- Statistics from Kruskal-Wallis analysis.

- $parameters <- Parameters from Kruskal-Wallis analysis.
}
\description{
Kruskal Wallis test for multiple comparison. Table and figures for
representing the results
}
\details{
Post hoc test is using the criterium Fisher's least significant difference.
Alpha is 0.05 by default.

The adjustment methods is Holm's method. There seems no reason to use the
unmodified Bonferroni correction because it is dominated by Holm's method,
which is also valid under arbitrary assumptions (Holm 1979).
}
\note{
Future improvements:

- The same without plyr

- Add Levenne test to table (car::leveneTest()).
}
\examples{
A <- agkruskalfigs(df0 = iris, x = "Species", y = "Petal.Length",
             lettersheight = 1)
A$plots$BarPlot
A$plots$Densities
A$tables$kw

}
\references{
Holm, S. (1979). A simple sequentially rejective multiple test procedure.
    Scandinavian Journal of Statistics 6, 65–70.
}
\seealso{
\url{http://www.biostathandbook.com/kruskalwallis.html}
for help on Kruskall Wallis analysis. Also
\code{\link[agricolae]{kruskal}},
\code{\link[ggpubr]{ggdensity}} and
\code{\link[plyr]{ddply}} to see the details of the functions used.
}
\author{
Alfonso Garmendia (Universitat Politècnica de València)
}
